@@ -1,7 +1,7 @@
 #! /usr/bin/perl
 
 # ex:ts=8 sw=4:
-# $OpenBSD: Quirks.pm,v 1.1760 2025/10/26 19:27:30 kn Exp $
+# $OpenBSD: Quirks.pm,v 1.1761 2025/11/01 14:28:23 sthen Exp $
 #
 # Copyright (c) 2009 Marc Espie <espie@openbsd.org>
 #
@@ -520,7 +520,7 @@ setup_obsolete_reason(
 	3 => 'canto',
 	6 => 'py-mini-amf',
 	6 => 'py3-mini-amf',
-	44 => 'qucs-s',
+	9 => 'qucs-s',
 	3 => 'qt4',
 	3 => 'qt4-examples',
 	3 => 'qt4-html',
@@ -531,7 +531,7 @@ setup_obsolete_reason(
 	1 => 'antlr3',
 	6 => 'enigmail',
 	6 => 'enigmail-seamonkey',
-	29 => 'google-compute-engine',
+	4 => 'google-compute-engine',
 	3 => 'bzr',
 	3 => 'bzr-svn',
 	6 => 'libvstr',
@@ -579,7 +579,7 @@ setup_obsolete_reason(
 	13 => 'py-xmpppy',
 	13 => 'py-yenc',
 	13 => 'py-zsi',
-	8 => 'tilecache',
+	3 => 'tilecache',
 	13 => 'py-configparser',
 	13 => 'py-decoratortools',
 	13 => 'py-paste',
@@ -696,13 +696,13 @@ setup_obsolete_reason(
 	7 => 'php-predis',
 	5 => 'virtuoso',
 	3 => 'upobsd',
-	9 => 'waagent',
+	4 => 'waagent',
 	3 => 'slim',
 	3 => 'slim-themes',
 	5 => 'ocaml-biniou',
 	5 => 'ocaml-easy-format',
 	5 => 'libdsm',
-	45 => 'direvent',
+	8 => 'direvent',
 	3 => 'climm',
 	13 => 'spe',
 	13 => 'py-Checker',
@@ -726,7 +726,7 @@ setup_obsolete_reason(
 	3 => 'kalarmcal',
 	5 => 'gnats',
 	3 => 'gnome-books',
-	46 => 'go-bootstrap',
+	6 => 'go-bootstrap',
 	13 => 'py-typing',
 	6 => 'py-funcsigs',
 	6 => 'py-statistics',
@@ -760,7 +760,7 @@ setup_obsolete_reason(
 	3 => 'libzapojit',
 	3 => 'librest',
 	3 => 'seahorse-sharing',
-	48 => 'electron',
+	14 => 'electron',
 	5 => 'xalan-j',
 	5 => 'opencdk',
 	5 => 'klaxon',
@@ -822,11 +822,11 @@ setup_obsolete_reason(
 	3 => 'shrip',
 # 7.4
 	3 => qr{^ruby30-},
-	53 => 'compton',
-	54 => 'depotdownloader',
-	55 => 'residualvm',
+	3 => 'compton',
+	16 => 'depotdownloader',
+	3 => 'residualvm',
 	5 => 'p5-Test-Group',
-	9 => 'thedarkmod',
+	4 => 'thedarkmod',
 	3 => 'qtav',
 	3 => 'ruby31-mysql',
 	3 => 'ruby32-mysql',
@@ -850,12 +850,12 @@ setup_obsolete_reason(
 	3 => 'freetype-doc',
 	6 => 'ipcheck',
 # 7.5
-	56 => 'psi',
-	56 => 'coccinella',
+	3 => 'psi',
+	3 => 'coccinella',
 	13 => 'py-snack',
 	5 => 'wxglade',
 	57 => 'barony',
-	58 => 'exa',
+	3 => 'exa',
 	6 => 'libgnomekbd',
 	3 => 'xmlrpc-c',
 	1 => 'pwntools',
@@ -885,7 +885,7 @@ setup_obsolete_reason(
 	64 => 'qsyncthingtray',
 	3 => 'h2o',
 	3 => 'smtube',
-	65 => 'goldendict',
+	3 => 'goldendict',
 	13 => 'mkplaylist',
 	1 => 'proteus',
 	1 => qr{^tryton},
@@ -899,10 +899,10 @@ setup_obsolete_reason(
 	3 => 'transcode',
 	3 => 'phonon-backend-gstreamer',
 	0 => 'gone',
-	66 => 'opensmtpd-extras',
-	66 => 'opensmtpd-extras-mysql',
-	66 => 'opensmtpd-extras-pgsql',
-	66 => 'opensmtpd-extras-redis',
+	3 => 'opensmtpd-extras',
+	3 => 'opensmtpd-extras-mysql',
+	3 => 'opensmtpd-extras-pgsql',
+	3 => 'opensmtpd-extras-redis',
 	13 => 'opensmtpd-extras-python',
 	3 => 'pdf2djvu',
 	3 => 'py3-fsb5',
@@ -916,13 +916,13 @@ setup_obsolete_reason(
 	5 => 'sofia-sip',
 	3 => 'pgfouine',
 	6 => 'py3-backports-strenum',
-	67 => 'vpnc',
+	3 => 'vpnc',
 	3 => 'seahorse-nautilus',
 	3 => 'libcryptui',
 	3 => 'gnome-screenshot',
 	3 => 'libgnome-keyring',
 	1 => 'fnaify',
-	68 => 'adsuck',
+	3 => 'adsuck',
 	6 => 'p5-Net-ICQ2000',
 	6 => 'vicq',
 	3 => 'iaxclient',
@@ -931,9 +931,9 @@ setup_obsolete_reason(
 	6 => 'mftrace',
 # 7.7
 	3 => 'pavuk',
-	69 => 'potamus',
+	13 => 'potamus',
 	3 => 'fleet',
-	70 => 'xml-security-c',
+	3 => 'xml-security-c',
 	3 => 'utox',
 	3 => 'vino',
 	3 => 'kipi-plugins',
@@ -965,7 +965,7 @@ setup_obsolete_reason(
 	5 => 'pycha',
 	10 => 'gotosocial',
 	5 => 'xsd',
-	29 => 'fastnetmon',
+	4 => 'fastnetmon',
 	3 => 'kross-interpreters-kf5',
 	3 => 'py3-notmuch',
 	3 => 'pop3d',
@@ -990,7 +990,7 @@ setup_obsolete_reason(
 	5 => 'libdazzle',
 	5 => 'clutter-gst',
 	3 => 'bruce',
-	29 => 'icedtea-web',
+	4 => 'icedtea-web',
 	3 => 'ruby34-rgen',
 	5 => 'libmusicbrainz',
 	5 => 'libunique',
@@ -1001,30 +1001,42 @@ setup_obsolete_reason(
 	3 => 'forcedattack',
 	3 => 'pathological',
 	3 => 'pyganim',
-	9 => 'renpy',
+	4 => 'renpy',
 	5 => 'pygame_sdl2',
 	3 => 'dynagen',
 	3 => 'termshark',
-	14 => 'py3-lief',
+	11 => 'py3-lief',
 	1 => 'rdp',
 	71 => 'mininet',
+	6 => 'dovecot-fts-xapian',
 );
 
-# though it's not yet used, these should be pkgnames, so that eventually
-# pkg_add is able to act on it
+# these should be pkgnames, there was some hope that pkg_add might later
+# be able to act on these directly.
 my $obsolete_suggestion = {
-	'xgrab' => [qw(scrot xwd)],
-	'dkim-milter' => 'opendkim',
-	'qhacc' => [qw(homebank gnucash kmymoney)],
-	'qgo' => 'kigo',
-	'beediff' => 'kompare',
-	'sqliteman' => [qw(sqlitebrowser kexi)],
-	'gbirthday' => 'qbirthday',
-	'qlandkartegt' => 'qmapshack',
-	'keepassx' => 'keepassxc',
+# 7.0
 	'gotweb' => 'gotwebd',
 	'compton' => 'picom',
+	'qucs-s' => [qw(xschem kicad)],
+# 7.1
+	'tilecache' => 'mapproxy',
+# 7.2
 	'exa' => 'eza',
+	'go-bootstrap' => 'go',
+# 7.4
+	'depotdownloader' => 'steamctl',
+	'residualvm' => 'scummvm',
+# 7.5
+	'coccinella' => [qw(dino mcabber gajim pidgin)],
+	'goldendict' => 'goldendict-ng',
+	'psi' => [qw(dino mcabber gajim pidgin)],
+# 7.6
+	'opensmtpd-extras' => [qw(opensmtpd-table-ldap opensmtpd-table-passwd opensmtpd-table-socketmap opensmtpd-table-sqlite)],
+	'opensmtpd-extras-mysql' => 'opensmtpd-table-mysql',
+	'opensmtpd-extras-pgsql' => 'opensmtpd-table-postgresql',
+	'opensmtpd-extras-redis' => 'opensmtpd-table-redis',
+# 7.9
+	'dovecot-fts-xapian' => 'dovecot-fts-flatcurve',
 };
 
 # reasons for obsolete packages
@@ -1033,37 +1045,23 @@ my $obsolete_message = {
 	1 => "no benefit to being packaged",
 	2 => "no longer maintained and full of security holes",
 	3 => "no longer maintained upstream",
+	4 => "unmaintained port that was blocking other changes in ports",
 	5 => "outdated and/or no longer required by other ports",
 	6 => "no longer useful",
 	7 => "removed in favor of using the language's package manager",
-	8 => "no longer maintained upstream, consider mapproxy as an alternative",
-	9 => "removed, needs a port maintainer",
+	8 => "crashes in many different ways at runtime",
+	9 => "not working correctly",
 	10 => "other OS suggested, or see https://docs.gotosocial.org/en/latest/advanced/builds/nowasm/",
 	11 => "no longer packageable",
 	12 => "use the alternative plugin distributed with roundcube instead (markasjunk, managesieve)",
 	13 => "has a dependency on obsolete software",
-	14 => "port needs updating",
+	14 => "horrible ecosystem",
 	15 => "use rspamd's internal milter support instead",
-	29 => "unmaintained port that was blocking other changes in ports",
-	44 => "qucs-s Qt4 UI not working correctly, suggest xschem or kicad's eeschema instead",
-	45 => "crashes in many different ways at runtime",
-	46 => "moved to binary bootstraps",
+	16 => "dependencies for recent versions can't be met",
 	47 => "DNS network daemon running as root and not using random source ports. use DNS64 support in unbound or isc-bind",
-	48 => "horrible ecosystem",
 	51 => "no longer maintained upstream, consider using socat or SSH",
-	53 => "no longer maintained upstream, consider migrating to picom",
-	54 => "dependencies for recent versions can't be met (dotnet), consider switching to steamctl",
-	55 => "residualvm has been merged into scummvm",
-	56 => "outdated, fails to establish TLS connections/cannot login, use dino, mcabber, gajim or pidgin",
 	57 => "frequent breakage with new versions, required openal audio backend has been orphaned for > 1 year",
-	58 => "abandoned upstream, use eza as a drop-in replacement",
 	64 => "no longer maintained upstream, crashes when showing the Syncthing web interface, use a browser",
-	65 => "superseded by goldendict-ng",
-	66 => "superseded by opensmtpd-table-*",
-	67 => "unmaintained upstream, outdated for decades, only supports old crypto, expected dhclient",
-	68 => "unmaintained upstream, outdated for decades, does not work, expected dhclient, use unwind.conf(5) 'block list file' instead",
-	69 => "no longer maintained upstream, does not support ffmpeg > 6",
-	70 => "retired upstream, no longer needed, only consumer security/libdigidocpp switched to textproc/libxml + security/xmlsec",
 	71 => "stale fork, requires Python 2, wants long gone switch(4), example does nothing (may destroy existing interfaces)",
 };
 
@@ -1270,8 +1268,6 @@ my $cve = {
 	'www/apache-httpd,-main' => 'apache-httpd-<2.4.35',
 	'www/bozohttpd' => 'bozohttpd-<20130711p0',
 	'www/chromium' => 'chromium-<69.0.3497.100',
-	'www/drupal7/core7' => 'drupal->=7.0,<7.60',
-	'www/drupal7/theme-newsflash' => 'drupal7-theme-newsflash-<2.5',
 	'www/gitea' => 'gitea-<1.7.6',
 	'www/hiawatha' => 'hiawatha-<10.8.4',
 	'www/iridium' => 'iridium-<2018.5.67',
